From ddebf02c254ec7701f9e8b2a838d1b31a4043d63 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Andreas=20Kusalananda=20K=C3=A4h=C3=A4ri?=
 <ak4@sanger.ac.uk>
Date: Wed, 23 Apr 2008 13:25:43 +0000
Subject: [PATCH] Increase $long_slice_count from 100 to 125.  Since the 'MT'
 chromosome in human is number 118 in length, no gene, %gc, or SNP density
 features were being calculated for it.

---
 misc-scripts/density_feature/gene_density_calc.pl | 9 +++++----
 misc-scripts/density_feature/percent_gc_calc.pl   | 5 ++---
 misc-scripts/density_feature/variation_density.pl | 7 ++++---
 3 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/misc-scripts/density_feature/percent_gc_calc.pl b/misc-scripts/density_feature/percent_gc_calc.pl
index 4b1930d848..ae3e599109 100644
--- a/misc-scripts/density_feature/percent_gc_calc.pl
+++ b/misc-scripts/density_feature/percent_gc_calc.pl
@@ -36,9 +36,8 @@ my $db = new Bio::EnsEMBL::DBSQL::DBAdaptor(-host => $host,
 					    -dbname => $dbname);
 
 
-my $bin_count = 150;
-my $long_slice_count = 100;
-
+my $bin_count        = 150;
+my $long_slice_count = 125;
 
 #
 # Check wether the script should run on given database
diff --git a/misc-scripts/density_feature/variation_density.pl b/misc-scripts/density_feature/variation_density.pl
index 6e80a3e744..6f89147ec9 100644
--- a/misc-scripts/density_feature/variation_density.pl
+++ b/misc-scripts/density_feature/variation_density.pl
@@ -1,6 +1,7 @@
 #
 # calculates the variation density from given core database
-# It finds Variation database by itself using naming convention s/core/variation/
+# It finds Variation database by itself using naming convention
+# s/core/variation/
 #
 #
 
@@ -17,8 +18,8 @@ use Getopt::Long;
 use Data::Dumper;
 $Data::Dumper::Maxdepth = 2;
 
-my $bin_count = 150;
-my $long_slice_count = 100;
+my $bin_count        = 150;
+my $long_slice_count = 125;
 
 my ( $host, $user, $pass, $port, $dbname  );
 
diff --git a/misc-scripts/density_feature/gene_density_calc.pl b/misc-scripts/density_feature/gene_density_calc.pl
index f9ac1c9cc2..b793532fc1 100644
--- a/misc-scripts/density_feature/gene_density_calc.pl
+++ b/misc-scripts/density_feature/gene_density_calc.pl
@@ -7,8 +7,9 @@
 # It will only run on databases with genes ...
 #
 
 # I think the right thing here is too generate densities on the biggest 50-100 toplevel slices ...
 # The website will be happy with about 150 bins I think.
 
 
 use strict;
@@ -18,8 +19,8 @@ use Bio::EnsEMBL::DensityType;
 use Bio::EnsEMBL::DensityFeature;
 use Getopt::Long;
 
-my $bin_count = 150;
-my $long_slice_count = 100;
+my $bin_count        = 150;
+my $long_slice_count = 125;
 
 
 my ( $host, $user, $pass, $port, $dbname  );
@@ -7,8 +7,9 @@
 #
 
-# I think the right thing here is too generate densities on the biggest 50-100 toplevel slices ...
-# The website will be happy with about 150 bins I think.
+# I think the right thing here is too generate densities on the longest
+# 125 toplevel slices... The website will be happy with about 150 bins I
+# think.
 
 
-- 
GitLab